@@ -1,4 +1,5 @@
 import json
+import html
 import os
 
 times = {}
@@ -7,12 +8,12 @@ path_to_files = "/tmp/literature-clock/docs/times"
 
 for json_file in os.listdir(path_to_files):
     with open(os.path.join(path_to_files, json_file), "r") as f:
-        time_stamp = "_".join(json_file.split(".")[0].split("_"))
-        times[time_stamp.replace("_", ":")] = [
+        timestamp = json_file.split(".")[0].replace("_", ":")
+        times[timestamp] = [
             {
-                "start": d["quote_first"],
-                "time": d["quote_time_case"],
-                "end": d["quote_last"],
+                "start": html.unescape(d["quote_first"]),
+                "time": html.unescape(d["quote_time_case"]),
+                "end": html.unescape(d["quote_last"]),
                 "title": d["title"],
                 "author": d["author"],
             }
@@ -20,4 +21,4 @@ for json_file in os.listdir(path_to_files):
         ]
 
 with open("./src/times.json", "w") as f:
-    json.dump(times, f)
+    json.dump(times, f, indent=2, sort_keys=True)
